import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["autoPlay", "controls", "hlsConfig", "playerRef", "src", "title"];
import { createRef, useEffect } from 'react';
import Hls from 'hls.js';
import PropTypes from 'prop-types';
import { BASE_CLASS, HLS_DEFAULT_TITLE } from '../settings/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
var HLSPlayer = function HLSPlayer(_ref) {
  var autoPlay = _ref.autoPlay,
    controls = _ref.controls,
    hlsConfig = _ref.hlsConfig,
    _ref$playerRef = _ref.playerRef,
    playerRef = _ref$playerRef === void 0 ? /*#__PURE__*/createRef() : _ref$playerRef,
    src = _ref.src,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? HLS_DEFAULT_TITLE : _ref$title,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  useEffect(function () {
    var hls;
    function _initPlayer() {
      if (hls !== undefined) {
        hls.destroy();
      }
      var newHls = new Hls(_extends({
        enableWorker: false
      }, hlsConfig));
      if (playerRef.current !== null) {
        newHls.attachMedia(playerRef.current);
      }
      newHls.on(Hls.Events.MEDIA_ATTACHED, function () {
        newHls.loadSource(src);
        newHls.on(Hls.Events.MANIFEST_PARSED, function () {
          if (autoPlay) {
            var _playerRef$current;
            /* eslint-disable no-console */
            playerRef == null ? void 0 : (_playerRef$current = playerRef.current) == null ? void 0 : _playerRef$current.play().catch(function () {
              return console.log('Unable to autoplay prior to user interaction with the dom.');
            });
          }
        });
      });
      newHls.on(Hls.Events.ERROR, function (event, data) {
        if (data.fatal) {
          switch (data.type) {
            case Hls.ErrorTypes.NETWORK_ERROR:
              newHls.startLoad();
              break;
            case Hls.ErrorTypes.MEDIA_ERROR:
              newHls.recoverMediaError();
              break;
            default:
              _initPlayer();
              break;
          }
        }
      });
      hls = newHls;
    }

    // Check for Media Source support
    if (Hls.isSupported()) {
      _initPlayer();
    }
    return function () {
      if (hls !== undefined) {
        hls.destroy();
      }
    };
  }, [autoPlay, hlsConfig, playerRef, src]);
  var nativePlayerProps = {
    autoPlay: autoPlay,
    src: src
  };
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS + "-hlsPlayer",
    children: /*#__PURE__*/_jsx("video", _extends({
      controls: controls,
      className: BASE_CLASS + "-hlsPlayerVideo",
      title: title,
      ref: playerRef
    }, Hls.isSupported() === false ? nativePlayerProps : {}, props))
  });
};
export default HLSPlayer;